# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from .models import Carriage, Delivery


class CarriageAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'slug', 'description',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('code', 'name')
    list_display = ('get_status_display', 'code', 'name', 'description', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {"slug": ("name",)}


class DeliveryAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'transport_by', 'carriage',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('transport_by', 'carriage')
    list_display = ('get_status_display', 'code', 'transport_by', 'carriage', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


admin.site.register(Delivery, DeliveryAdmin)
admin.site.register(Carriage, CarriageAdmin)
