# -*- coding: utf-8 -*-

from rest_framework import serializers

from .. import models


class CarriageSerializer(serializers.ModelSerializer):
    status_name = serializers.SerializerMethodField()

    class Meta:
        model = models.Carriage
        fields = '__all__'

    def get_status_name(self, obj):
        return obj.get_status_display()


class CarriageSerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Carriage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class CarriageSerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Carriage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class DeliverySerializer(serializers.ModelSerializer):
    status_name = serializers.SerializerMethodField()
    transport_by_name = serializers.SerializerMethodField()
    carriage_name = serializers.SerializerMethodField()

    class Meta:
        model = models.Delivery
        fields = '__all__'

    def get_status_name(self, obj):
        return obj.get_status_display()

    def get_transport_by_name(self, obj):
        return obj.get_transport_by_display()

    def get_carriage_name(self, obj):
        return obj.carriage.name


class DeliverySerializerCreate(serializers.ModelSerializer):
    class Meta:
        model = models.Delivery
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')


class DeliverySerializerUpdate(serializers.ModelSerializer):
    class Meta:
        model = models.Delivery
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
