# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


@python_2_unicode_compatible
class Carriage(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores carriages:
    frw - CARRIAGE FORWARD - PORTO ASSEGNATO
    pad - CARRIAGE PAID - PORTO FRANCO
    exw - EX WORKS" - EX WORKS
    pdc - CARRIAGE PAID W/CHARGE - PORTO FRANCO CON ADDEBITO
    """
    code = models.CharField(
        primary_key=True,
        max_length=3,
        verbose_name=_("code")
    )
    name = models.CharField(
        max_length=50,
        unique=True,
        verbose_name=_("name")
    )
    slug = models.SlugField(
        unique=True,
        max_length=50,
        verbose_name=_("slug"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description")
    )

    class Meta:
        verbose_name = _('carriage')
        verbose_name_plural = _('carriages')
        ordering = ('ordering', 'name')
        permissions = (
            ("list_carriage", "Can list carriage"),
            ("detail_carriage", "Can detail carriage"),
            ("disable_carriage", "Can disable carriage"),
        )

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class Delivery(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores deliveries
    """
    code = models.CharField(
        primary_key=True,
        max_length=3,
        verbose_name=_("code")
    )
    transport_by = models.CharField(
        max_length=3,
        choices=settings.CARRIAGE_TRANSPORTBY_DEF,
        verbose_name=_('transport by'),
    )
    carriage = models.ForeignKey(
        Carriage,
        verbose_name=_('carriage'),
    )

    class Meta:
        verbose_name = _('delivery')
        verbose_name_plural = _('deliveries')
        ordering = ('ordering', 'transport_by', 'carriage')
        permissions = (
            ("list_delivery", "Can list delivery"),
            ("detail_delivery", "Can detail delivery"),
            ("disable_delivery", "Can disable delivery"),
        )

    def __str__(self):
        return "{} - {}".format(
            self.get_transport_by_display(),
            self.carriage,
        )
